/**
 * @file
 * JavaScript integration between Kendo UI charts and Drupal.
 */
(function (Drupal, jQuery, once, kendo) {
  Drupal.behaviors.chartsKendoUi = {
    attach(context) {
      once('charts-kendo-ui-init', '.charts-kendo-ui', context).forEach(function(element) {
        try {
          // If the chart data is available in the data-chart attribute, use that
          if (element.hasAttribute('data-chart')) {
            const config = JSON.parse(element.getAttribute('data-chart'));
            const chartType = config?.seriesDefaults?.type ?? 'line';
            console.log(chartType);
            if (chartType && !(chartType === 'gauge')) {
              // Initialize the chart with the configuration
              jQuery(element).kendoChart(config);
            }
            else {
              // If the chart type is 'gauge', update the config to only what
              // is needed.
              const newConfig = {
                'value': config?.series[0] ?? 0,
                'scale': {
                  'min': config?.valueAxis?.min ?? 0,
                  'max': config?.valueAxis?.max ?? 100,
                },
                'centerTemplate': '#: value #%',
              };
              jQuery(element).kendoArcGauge(newConfig);
            }

            // Debug output if needed
            if (
              element.nextElementSibling &&
              element.nextElementSibling.hasAttribute('data-charts-debug-container')
            ) {
              element.nextElementSibling.querySelector('code').innerText =
                JSON.stringify(config, null, 2);
            }
          }
        } catch (e) {
          console.error('Error initializing chart:', e);
        }
      });
    }
  };
})(Drupal, jQuery, once, kendo);
